OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Тэмдэглэж авах",
    "You bookmarked \"%s\"" : "Тэмдэглэж авлаа \"%s\"",
    "You deleted \"%s\"" : "\"%s\"-ийг та устгалаа",
    "%1$s deleted \"%2$s\"" : "\"%2$s\"-ийг %1$s устгалаа ",
    "Someone deleted \"%s\"" : "\"%s\" устгагдлаа",
    "You created folder \"%s\"" : "Та \"%s\" фолдерыг үүсгэлээ",
    "%1$s created folder \"%2$s\"" : "\"%2$s\" фолдерыг %1$s шинээр үүсгэлээ",
    "Someone created folder \"%s\"" : "\"%s\" фолдерыг шинээр үүсгэлээ",
    "You moved folder \"%s\"" : "Та \"%s\" фолдерыг  хөдөлгөлөө",
    "%1$s moved folder \"%2$s\"" : "\"%2$s\" фолдерыг %1$s хөдөлгөлөө",
    "Details" : "Дэлгэрэнгүй",
    "Rename" : "Нэрлэнэ үү",
    "Copy link" : "Холбоос хуулах",
    "Move" : "Зөөх",
    "Select all" : "бүгдийг сонгох",
    "Go back" : "Буцах",
    "New" : "Шинэ",
    "New folder" : "Шинэ хавтас",
    "Search" : "Хайх",
    "_%n folder_::_%n folders_" : ["%n хавтас","%n хавтас"],
    "Choose folder" : "Хавтас сонгого уу",
    "Submit" : "мэдэгдэх",
    "Cancel" : "болиулах",
    "Recent" : "Сүүлийн үеийн",
    "Shared with you" : "тантай хуваалцсан",
    "Files" : "файлууд",
    "Delete" : "Устгах",
    "Title" : "Цол/Албан тушаал",
    "Link" : "Холбоос",
    "Tags" : "Tag-үүд",
    "Notes" : "Шинэ ",
    "Open file" : "Файл онгойлгох",
    "Owner" : "Эзэмшигч",
    "Sharing" : "Түгээх",
    "Share link" : "Холбоос хуваалцах",
    "Allow editing" : "Засварлахыг зөвшөөрөх",
    "Privacy" : "Хувийн нууц",
    "Folder" : "Хавтас",
    "Save" : "Хадгалах"
},
"nplurals=2; plural=(n != 1);");
